declare type CommandUniqueId = number;

export declare const complete: {
    repl(payload: CompletePayload): Promise<CompletionResults>;
};

declare type CompletePayload = {
    code: string;
    line?: number;
    column?: number;
};

declare type CompletionMatch = CompletionResult;

declare type CompletionResult = {
    name: string;
    type: string;
    description: string;
    full_name: string;
};

declare type CompletionResults = {
    matches: CompletionMatch[];
};

export declare function exec(payload: ExecPayload): Promise<ExecReturnValue>;

declare type ExecParams = {
    id: CommandUniqueId;
    error: string | null;
    result: string | null;
    stdout: string | null;
    stderr: string | null;
};

declare type ExecPayload = {
    code: string;
    context?: Record<string, unknown>;
};

declare type ExecReturnValue = Omit<ExecParams, 'id'>;

export declare function format(payload: FormatPayload): Promise<FormatReturnValue>;

declare type FormatParams = {
    id: CommandUniqueId;
    result: string | null;
    error: string | null;
};

declare type FormatPayload = {
    code: string;
};

declare type FormatReturnValue = Omit<FormatParams, 'id'>;

export declare const init: () => Promise<Worker>;

export declare function install(packages: string[]): Promise<InstallReturnValue>;

declare type InstallParams = {
    id: CommandUniqueId;
    success: boolean;
    error: string | null;
};

declare type InstallReturnValue = Omit<InstallParams, 'id'>;

export { }
